@@ -3,8 +3,8 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         .out_dir("src")
         .build_client(false)
         .compile(
-            &["proto/blog/service.proto"],
-            &["."],
+            &["myblog-proto/proto/blog/service.proto"],
+            &["myblog-proto"],
         )?;
     Ok(())
 }
\ No newline at end of file
